@@ -1,6 +1,7 @@
 #!/bin/bash
 
-REAL_PATH=$(python -c "import os,sys;print(os.path.realpath('$0'))")
+# Move to top level directory
+REAL_PATH=$(realpath $0)
 cd "$(dirname "$REAL_PATH")/.."
 
 RES=0
